RRuleTextDelegate class

Implementers

Constructors

RRuleTextDelegate()

Properties

byDayInMonth → String
no setter
byNthDayInMonth → String
no setter
date → String
no setter
day → String
no setter
days → String
no setter
daysInMonth → List<String>
no setter
end → String
no setter
endsAfter → String
no setter
endsOnDate → String
no setter
every → String
no setter
excludeDate → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
instances → String
no setter
locale → String
no setter
month → String
no setter
months → String
no setter
neverEnds → String
no setter
of → String
no setter
on → String
no setter
periods → List<String>
no setter
repeat → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weeks → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited